==> ELAN-3_3_0-src.zip: ELAN-3.3.0-src/src/java/mpi/eudico/server/corpora/clomimpl/abstr/Parser.java <==
/*
 * File:     Parser.java
 * Project:  MPI Linguistic Application
 * Date:     12 December 2007
 *
 * Copyright (C) 2001-2008  Max Planck Institute for Psycholinguistics
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*
 * Created on Jun 3, 2004
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package mpi.eudico.server.corpora.clomimpl.abstr;

import mpi.eudico.server.corpora.clom.DecoderInfo;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Locale;


/**
 * @author hennie
 *
 * Note: for historic reasons all getters take the file to be parsed as a
 * parameter. This could be dropped in the future.
 * @version Dec 2006: added getter for the Annotator of a tier
 */
public abstract class Parser {
    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getMediaFile(String fileName) {
        return null;
    }

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract ArrayList getMediaDescriptors(String fileName);

    /**
     * Returns the Linked File descriptors; only applicable to eaf
     *
     * @param fileName the file name
     *
     * @return a List of linked file descriptors
     */
    public ArrayList getLinkedFileDescriptors(String fileName) {
        return null;
    }

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getSVGFile(String fileName) {
        return null;
    }

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getAuthor(String fileName) {
        return null;
    }

    /**
     * Returns a list of the document (header) properties.
     *
     * @param fileName the file to be parsed
     *
     * @return a list of the document (header) properties
     */
    public ArrayList getTranscriptionProperties(String fileName) {
        return null;
    }

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract ArrayList getLinguisticTypes(String fileName);

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract ArrayList getTimeOrder(String fileName);

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract HashMap getTimeSlots(String fileName);

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public HashMap getControlledVocabularies(String fileName) {
        return null;
    }

    /**
     * Returns the names of the Tiers that are present in the Transcription
     * file
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract ArrayList getTierNames(String fileName);

    /**
     * DOCUMENT ME!
     *
     * @param tierName DOCUMENT ME!
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract String getParticipantOf(String tierName, String fileName);

    /**
     * Returns the annotator of a tier, will not be present in a lot of
     * file types.
     *
     * @param tierName the tier id
     * @param fileName the file to parse
     *
     * @return the annotator
     */
    public String getAnnotatorOf(String tierName, String fileName) {
        return null;
    }

    /**
     * DOCUMENT ME!
     *
     * @param tierName DOCUMENT ME!
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract String getLinguisticTypeIDOf(String tierName,
        String fileName);

    /**
     * DOCUMENT ME!
     *
     * @param tierName DOCUMENT ME!
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public Locale getDefaultLanguageOf(String tierName, String fileName) {
        return new Locale("US", "en", "");
    }

    /**
     * DOCUMENT ME!
     *
     * @param tierName DOCUMENT ME!
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract String getParentNameOf(String tierName, String fileName);

    /**
     * Returns a List with the Annotations for this Tier. Each
     * AnnotationRecord contains begin time, end time and text values
     *
     * <p>
     * MK:02/06/10<br> Elements of List are no CLOM/ACM Annotations but yet
     * another List of String . The inner List is interpreted as variant
     * record in DAFTranscriptionStore.loadTranscription
     * </p>
     *
     * @param tierName DOCUMENT ME!
     * @param fileName DOCUMENT ME!
     *
     * @return List of List of String
     */
    public abstract ArrayList getAnnotationsOf(String tierName, String fileName);

    /**
     * Sets the decoder info object for the parser. Empty implementation.
     *
     * @param decoderInfo the decoderinfo object
     */
    public void setDecoderInfo(DecoderInfo decoderInfo) {
        // stub
    }
}

==> ELAN-3_8_1-src.zip: ELAN-3.8.1-src/src/java/mpi/eudico/server/corpora/clomimpl/abstr/Parser.java <==
/*
 * File:     Parser.java
 * Project:  MPI Linguistic Application
 * Date:     25 August 2009
 *
 * Copyright (C) 2001-2009  Max Planck Institute for Psycholinguistics
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*
 * Created on Jun 3, 2004
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package mpi.eudico.server.corpora.clomimpl.abstr;

import mpi.eudico.server.corpora.clom.DecoderInfo;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;


/**
 * @author hennie
 *
 * Note: for historic reasons all getters take the file to be parsed as a
 * parameter. This could be dropped in the future.
 * @version Dec 2006: added getter for the Annotator of a tier
 */
public abstract class Parser {
    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getMediaFile(String fileName) {
        return null;
    }

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract ArrayList getMediaDescriptors(String fileName);

    /**
     * Returns the Linked File descriptors; only applicable to eaf
     *
     * @param fileName the file name
     *
     * @return a List of linked file descriptors
     */
    public ArrayList getLinkedFileDescriptors(String fileName) {
        return null;
    }

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getSVGFile(String fileName) {
        return null;
    }

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getAuthor(String fileName) {
        return null;
    }

    /**
     * Returns a list of the document (header) properties.
     *
     * @param fileName the file to be parsed
     *
     * @return a list of the document (header) properties
     */
    public ArrayList getTranscriptionProperties(String fileName) {
        return null;
    }

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract ArrayList getLinguisticTypes(String fileName);

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract ArrayList getTimeOrder(String fileName);

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract HashMap getTimeSlots(String fileName);

    /**
     * DOCUMENT ME!
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public HashMap getControlledVocabularies(String fileName) {
        return null;
    }

    /**
     * Returns a map of id - ext ref objects pairs.
     *
     * @param fileName the transcription file
     * @return a map with id - object mappings, null by default
     */
    public Map getExternalReferences(String fileName) {
        return null;
    }

    /**
     * Returns the names of the Tiers that are present in the Transcription
     * file
     *
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract ArrayList getTierNames(String fileName);

    /**
     * DOCUMENT ME!
     *
     * @param tierName DOCUMENT ME!
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract String getParticipantOf(String tierName, String fileName);

    /**
     * Returns the annotator of a tier, will not be present in a lot of
     * file types.
     *
     * @param tierName the tier id
     * @param fileName the file to parse
     *
     * @return the annotator
     */
    public String getAnnotatorOf(String tierName, String fileName) {
        return null;
    }

    /**
     * DOCUMENT ME!
     *
     * @param tierName DOCUMENT ME!
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract String getLinguisticTypeIDOf(String tierName,
        String fileName);

    /**
     * DOCUMENT ME!
     *
     * @param tierName DOCUMENT ME!
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public Locale getDefaultLanguageOf(String tierName, String fileName) {
        return new Locale("US", "en", "");
    }

    /**
     * DOCUMENT ME!
     *
     * @param tierName DOCUMENT ME!
     * @param fileName DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public abstract String getParentNameOf(String tierName, String fileName);

    /**
     * Returns a List with the Annotations for this Tier. Each
     * AnnotationRecord contains begin time, end time and text values
     *
     * <p>
     * MK:02/06/10<br> Elements of List are no CLOM/ACM Annotations but yet
     * another List of String . The inner List is interpreted as variant
     * record in DAFTranscriptionStore.loadTranscription
     * </p>
     *
     * @param tierName DOCUMENT ME!
     * @param fileName DOCUMENT ME!
     *
     * @return List of List of String
     */
    public abstract ArrayList getAnnotationsOf(String tierName, String fileName);

    /**
     * Sets the decoder info object for the parser. Empty implementation.
     *
     * @param decoderInfo the decoderinfo object
     */
    public void setDecoderInfo(DecoderInfo decoderInfo) {
        // stub
    }
}
